@@ -1,4 +1,10 @@
+import sys
+
 from ghc.cli import parse_options
+from ghc.exceptions import (
+    GitHubRequestError, GitHubTokenUnsetError, ReportError,
+    TemplateNotFoundError
+)
 from ghc.github import search_repositories_by_topics
 from ghc.logger import get_logger
 from ghc.reporter import report
@@ -8,27 +14,33 @@ logger = get_logger(__name__)
 
 
 def main() -> bool:
-    options = parse_options()
+    logger.info('START')
 
     try:
+        options = parse_options()
+
         result = search_repositories_by_topics(
             options.token, owner=options.owner, topics=options.topics)
-    except Exception as err:
-        logger.error(err)
-        logger.error('Failed to request to GitHub')
-        return False
-    else:
         logger.info('Succeeded to request to GitHub')
 
-    try:
         report(result, fmt=options.fmt, filename=options.filename)
-    except Exception as err:
+        logger.info('Completed report!!')
+    except GitHubTokenUnsetError as err:
+        logger.error(err)
+        sys.exit(1)
+    except GitHubRequestError as err:
+        logger.error(err)
+        logger.error('Failed to request to GitHub')
+        sys.exit(1)
+    except (TemplateNotFoundError, ReportError) as err:
         logger.error(err)
         logger.error('Failed to output the result')
-        return False
-    else:
-        logger.info('Completed report!!')
+        sys.exit(1)
+    except Exception as err:
+        logger.error(err)
+        sys.exit(1)
 
+    logger.info('DONE')
     return True
 
 
